@@ -1,8 +1,10 @@
+use crate::Version;
+
 use super::{Message, ScriptInfo, ScriptType};
 use std::io::Write;
 
 /// Trait that can be implemented on a script abstraction struct\
-/// The implementer should provide [Scripter::script_type], [Scripter::name] and [Scripter::hooks]\
+/// The implementer should provide [Scripter::script_type], [Scripter::name], [Scripter::hooks] and [Scripter::version]\
 ///  The struct should call [Scripter::execute]\
 ///  ```rust, no_run
 ///  # use rscript::*;
@@ -33,6 +35,9 @@ use std::io::Write;
 ///     fn hooks() -> &'static [&'static str] {
 ///         &[MyHook::NAME]
 ///     }
+///     fn version() -> Version {
+///         Version::Exact("main_crate-0.1.0".into())
+///     }
 ///  }
 ///
 ///  fn main() {
@@ -47,6 +52,8 @@ pub trait Scripter {
     fn script_type() -> ScriptType;
     /// The hooks that the script is interested in
     fn hooks() -> &'static [&'static str];
+    /// The version of the program that the script will run against, when running the script with [Scripter::execute] it will use this version to check if there is an incompatibility between the script and the program
+    fn version() -> Version;
 
     // Provided methods
     /// Convenient method to read a hook from stdin
@@ -63,7 +70,7 @@ pub trait Scripter {
     ///
     /// Example of a user function:
     /// ```rust
-    /// # use rscript::Hook;
+    /// # use rscript::{Version, Hook};
     /// # use rscript::scripting::Scripter;
     /// # #[derive(serde::Serialize, serde::Deserialize)]
     /// # struct MyHook{}
@@ -76,6 +83,7 @@ pub trait Scripter {
     /// #   fn name() -> &'static str { todo!() }
     /// #   fn script_type() -> rscript::ScriptType { todo!() }
     /// #   fn hooks() -> &'static [&'static str] { todo!() }
+    /// #   fn version() -> Version { todo!() }
     /// # }
     ///
     /// fn run(hook_name: &str) {
@@ -95,7 +103,12 @@ pub trait Scripter {
         let message: Message = bincode::deserialize_from(&mut stdin).unwrap();
 
         if message == Message::Greeting {
-            let metadata = ScriptInfo::new(Self::name(), Self::script_type(), Self::hooks());
+            let metadata = ScriptInfo::new(
+                Self::name(),
+                Self::script_type(),
+                Self::hooks(),
+                Self::version(),
+            );
             bincode::serialize_into(&mut stdout, &metadata).unwrap();
             stdout.flush().unwrap();
 
